Coverage for /root/GitHubProjects/impacket/impacket/examples/ntlmrelayx/attacks/dcsyncattack.py: 86%

# Coverage for /root/GitHubProjects/impacket/impacket/examples/ntlmrelayx/attacks/dcsyncattack.py : 86%

## 7 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Impacket - Collection of Python classes for working with network protocols.

2#

3# SECUREAUTH LABS. Copyright (C) 2020 SecureAuth Corporation. All rights reserved.

4#

5# This software is provided under a slightly modified version

6# of the Apache Software License. See the accompanying LICENSE file

7# for more information.

8#

9# Description:

10# HTTP Attack Class

11# HTTP protocol relay attack

12#

13# Authors:

14# Alberto Solino (@agsolino)

15# Dirk-jan Mollema (@_dirkjan) / Fox-IT (https://www.fox-it.com)

16#

17 from impacket.examples.ntlmrelayx.attacks import ProtocolAttack

18 from impacket.examples.secretsdump import RemoteOperations, SAMHashes, NTDSHashes

19

20 PROTOCOL_ATTACK_CLASS = "DCSYNCAttack"

21

22 class DCSYNCAttack(ProtocolAttack):

23 """

24 This is the default HTTP attack. This attack only dumps the root page, though

25 you can add any complex attack below. self.client is an instance of urrlib.session

26 For easy advanced attacks, use the SOCKS option and use curl or a browser to simply

27 proxy through ntlmrelayx

28 """

29 PLUGIN_NAMES = ["DCSYNC"]

30 def run(self):

31 return